# Generated by Django 2.1.3 on 2018-11-15 11:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geonames_place', '0002_alter_field_geonames_id_on_place'),
    ]

    operations = [
        migrations.AddField(
            model_name='place',
            name='update_from_geonames',
            field=models.BooleanField(default=True),
        ),
    ]
